@@ -1,7 +1,7 @@
 package CloudFlare::Client;
 # ABSTRACT: Object Orientated Interface to CloudFlare client API
 
-use Modern::Perl '2012';
+use Modern::Perl '2013';
 use autodie      ':all';
 no  indirect     'fatal';
 use namespace::autoclean;
@@ -19,7 +19,7 @@ use LWP::UserAgent       6.02;
 use LWP::Protocol::https 6.02;
 use JSON::Any;
 
-our $VERSION = '0.03_9'; # TRIAL VERSION
+our $VERSION = '0.05_1'; # TRIAL VERSION
 
 # CF credentials
 has '_user' => (
@@ -173,7 +173,7 @@ CloudFlare::Client - Object Orientated Interface to CloudFlare client API
 
 =head1 VERSION
 
-version 0.03_9
+version 0.05_1
 
 =head1 SYNOPSIS
 
@@ -304,9 +304,7 @@ Construct a new API object
 
 Please report any bugs or feature requests to C<bug-cloudflare-client
 at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CloudFlare-Client>.
-I will be notified, and then you'll automatically be notified of
-progress on your bug as I make changes
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CloudFlare-Client>
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -318,7 +316,7 @@ Peter Roberts <me+dev@peter-r.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Peter Roberts.
+This software is Copyright (c) 2015 by Peter Roberts.
 
 This is free software, licensed under:
 
